@@ -5,15 +5,15 @@
 
 #include <R_ext/Rdynload.h>
 
-#define CDEF(name)  {#name, (DL_FUNC) &name, sizeof(name ## _t)/sizeof(name ## _t[0]), name ##_t}
+#define CDEF(name)  {#name, (DL_FUNC) &name, sizeof(name ## _typ)/sizeof(name ## _typ[0]), name ##_typ}
 #define CALLDEF(name, n)  {#name, (DL_FUNC) &name, n}
 
 
-static R_NativePrimitiveArgType R_bncoef_t[3] = {
+static R_NativePrimitiveArgType R_bncoef_typ[3] = {
     INTSXP, REALSXP, REALSXP
 };
 
-static R_NativePrimitiveArgType cl_clara_t[34] = {
+static R_NativePrimitiveArgType cl_clara_typ[34] = {
     /*n:*/ INTSXP, INTSXP, INTSXP, REALSXP, INTSXP, INTSXP, REALSXP, INTSXP,
     /*valmd:*/ REALSXP, INTSXP, INTSXP, /* rng_R: */ LGLSXP, /* pam_like:*/ LGLSXP,
     /*d_flag:*/ INTSXP,
@@ -23,7 +23,7 @@ static R_NativePrimitiveArgType cl_clara_t[34] = {
     /*tmp: */ REALSXP,INTSXP
 };
 
-static R_NativePrimitiveArgType cl_fanny_t[27] = {
+static R_NativePrimitiveArgType cl_fanny_typ[27] = {
     INTSXP, INTSXP, INTSXP, REALSXP, REALSXP,
     /*jdyss: */ INTSXP, REALSXP, INTSXP,  INTSXP, INTSXP, INTSXP,
     /*negbr: */ INTSXP, /*syl: */ REALSXP, REALSXP, REALSXP, REALSXP,
@@ -32,7 +32,7 @@ static R_NativePrimitiveArgType cl_fanny_t[27] = {
 };
 
 #ifdef _UNUSED_C_pam
-static R_NativePrimitiveArgType cl_pam_t[24] = {
+static R_NativePrimitiveArgType cl_pam_typ[24] = {
     INTSXP, INTSXP, INTSXP, REALSXP, REALSXP,
     /*jdyss: */ INTSXP, REALSXP, INTSXP,  INTSXP, INTSXP,
     /*nrepr: */ LGLSXP, INTSXP, /*radus: */ REALSXP, REALSXP, REALSXP, REALSXP,
@@ -41,17 +41,17 @@ static R_NativePrimitiveArgType cl_pam_t[24] = {
 };
 #endif
 
-static R_NativePrimitiveArgType spannel_t[12] = { // ./spannel.c :
+static R_NativePrimitiveArgType spannel_typ[12] = { // ./spannel.c :
     INTSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP,
     /*varss: */ REALSXP, REALSXP, REALSXP, REALSXP, INTSXP, INTSXP
 };
 
-static R_NativePrimitiveArgType sildist_t[] = {
+static R_NativePrimitiveArgType sildist_typ[] = {
     REALSXP, INTSXP, INTSXP, INTSXP, REALSXP, INTSXP,
     /* si: */ REALSXP, INTSXP, LGLSXP
 };
 
-static R_NativePrimitiveArgType twins_t[18] = {
+static R_NativePrimitiveArgType twins_typ[18] = {
     INTSXP, INTSXP, REALSXP, REALSXP, REALSXP,
     /* jdiss: */ INTSXP, REALSXP,
     INTSXP, INTSXP, INTSXP, INTSXP,
@@ -60,7 +60,7 @@ static R_NativePrimitiveArgType twins_t[18] = {
 };
 
 /* is only .C()-called from ../tests/sweep-ex.R : */
-static R_NativePrimitiveArgType cl_sweep_t[5] = {
+static R_NativePrimitiveArgType cl_sweep_typ[5] = {
     REALSXP, INTSXP, INTSXP, INTSXP, REALSXP
 };
 
